summaryrefslogtreecommitdiffstats
path: root/generic/tkInt.h
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-06 15:43:59 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2020-09-06 15:43:59 (GMT)
commit44f33f818f8d5a9716f4e3277703f2f9beb8796f (patch)
tree8fb600423d336b117ae3f53be91e3f1850098dfb /generic/tkInt.h
parentd2ab1fe96fa2eeb20d0bce978ec1242ecd06d0f6 (diff)
parented825e13f3d05988eacdfaf8e978377149b9302b (diff)
downloadtk-44f33f818f8d5a9716f4e3277703f2f9beb8796f.zip
tk-44f33f818f8d5a9716f4e3277703f2f9beb8796f.tar.gz
tk-44f33f818f8d5a9716f4e3277703f2f9beb8796f.tar.bz2
Merge 8.7
Diffstat (limited to 'generic/tkInt.h')
-rw-r--r--generic/tkInt.h42
1 files changed, 20 insertions, 22 deletions
diff --git a/generic/tkInt.h b/generic/tkInt.h
index 74f2501..4d83779 100644
--- a/generic/tkInt.h
+++ b/generic/tkInt.h
@@ -88,6 +88,11 @@
# define Tcl_UtfToChar16DString Tcl_UtfToUniCharDString
#endif
+
+#ifndef Tcl_GetParent
+# define Tcl_GetParent Tcl_GetMaster
+#endif
+
/*
* Macros used to cast between pointers and integers (e.g. when storing an int
* in ClientData), on 64-bit architectures they avoid gcc warning about "cast
@@ -359,9 +364,9 @@ typedef struct TkDisplay {
*/
Tcl_HashTable maintainHashTable;
/* Hash table that maps from a master's
* Tk_Window token to a list of slaves managed
* by that master. */
int geomInit;
#define TkGetGeomMaster(tkwin) (((TkWindow *)tkwin)->maintainerPtr != NULL ? \
@@ -442,9 +447,9 @@ typedef struct TkDisplay {
*/
int placeInit; /* 0 means tables below need initializing. */
- Tcl_HashTable masterTable; /* Maps from Tk_Window toke to the Master
+ Tcl_HashTable containerTable; /* Maps from Tk_Window token to the Container
* structure for the window, if it exists. */
- Tcl_HashTable slaveTable; /* Maps from Tk_Window toke to the Slave
+ Tcl_HashTable contentTable; /* Maps from Tk_Window token to the Content
* structure for the window, if it exists. */
/*
@@ -676,7 +681,7 @@ typedef struct TkMainInfo {
/* Top level of option hierarchy for this main
* window. NULL means uninitialized. Managed
* by tkOption.c. */
- Tcl_HashTable imageTable; /* Maps from image names to Tk_ImageMaster
+ Tcl_HashTable imageTable; /* Maps from image names to Tk_ImageModel
* structures. Managed by tkImage.c. */
int strictMotif; /* This is linked to the tk_strictMotif global
* variable. */
@@ -871,9 +876,9 @@ typedef struct TkWindow {
#endif /* TK_USE_INPUT_METHODS */
char *geomMgrName; /* Records the name of the geometry manager. */
struct TkWindow *maintainerPtr;
/* The geometry master for this window. The
* value is NULL if the window has no master or
* if its master is its parent. */
#if !defined(TK_USE_INPUT_METHODS) && (TCL_MAJOR_VERSION < 9)
XIC inputContext; /* XIM input context. */
int ximGeneration; /* Used to invalidate XIC */
@@ -1038,8 +1043,6 @@ typedef struct TkpClipMask {
|Button6Mask|Button7Mask|Button8Mask|Button9Mask)
-MODULE_SCOPE unsigned TkGetButtonMask(unsigned);
-
/*
* Object types not declared in tkObj.c need to be mentioned here so they can
* be properly registered with Tcl:
@@ -1271,13 +1274,12 @@ MODULE_SCOPE int Tk_WinfoObjCmd(ClientData clientData,
MODULE_SCOPE int Tk_WmObjCmd(ClientData clientData, Tcl_Interp *interp,
int objc, Tcl_Obj *const objv[]);
-MODULE_SCOPE int Tk_GetDoublePixelsFromObj(Tcl_Interp *interp,
- Tk_Window tkwin, Tcl_Obj *objPtr,
- double *doublePtr);
-MODULE_SCOPE int TkSetGeometryMaster(Tcl_Interp *interp,
- Tk_Window tkwin, const char *master);
-MODULE_SCOPE void TkFreeGeometryMaster(Tk_Window tkwin,
- const char *master);
+#define TkSetGeometryContainer TkSetGeometryMaster
+MODULE_SCOPE int TkSetGeometryContainer(Tcl_Interp *interp,
+ Tk_Window tkwin, const char *name);
+#define TkFreeGeometryContainer TkFreeGeometryMaster
+MODULE_SCOPE void TkFreeGeometryContainer(Tk_Window tkwin,
+ const char *name);
MODULE_SCOPE void TkEventInit(void);
MODULE_SCOPE void TkRegisterObjTypes(void);
@@ -1319,7 +1321,6 @@ MODULE_SCOPE int TkParsePadAmount(Tcl_Interp *interp,
int *pad1Ptr, int *pad2Ptr);
MODULE_SCOPE void TkFocusSplit(TkWindow *winPtr);
MODULE_SCOPE void TkFocusJoin(TkWindow *winPtr);
-MODULE_SCOPE int TkpAlwaysShowSelection(Tk_Window tkwin);
MODULE_SCOPE void TkpDrawCharsInContext(Display * display,
Drawable drawable, GC gc, Tk_Font tkfont,
const char *source, int numBytes, int rangeStart,
@@ -1341,7 +1342,6 @@ MODULE_SCOPE void TkpGetFontAttrsForChar(Tk_Window tkwin, Tk_Font tkfont,
MODULE_SCOPE void TkpDrawFrameEx(Tk_Window tkwin, Drawable drawable,
Tk_3DBorder border, int highlightWidth,
int borderWidth, int relief);
-MODULE_SCOPE Tcl_Obj * TkNewWindowObj(Tk_Window tkwin);
MODULE_SCOPE void TkpShowBusyWindow(TkBusy busy);
MODULE_SCOPE void TkpHideBusyWindow(TkBusy busy);
MODULE_SCOPE void TkpMakeTransparentWindowExist(Tk_Window tkwin,
@@ -1351,8 +1351,6 @@ MODULE_SCOPE void TkpCreateBusy(Tk_FakeWin *winPtr, Tk_Window tkRef,
TkBusy busy);
MODULE_SCOPE int TkBackgroundEvalObjv(Tcl_Interp *interp,
int objc, Tcl_Obj *const *objv, int flags);
-MODULE_SCOPE void TkSendVirtualEvent(Tk_Window tgtWin,
- const char *eventName, Tcl_Obj *detail);
MODULE_SCOPE Tcl_Command TkMakeEnsemble(Tcl_Interp *interp,
const char *nsname, const char *name,
ClientData clientData, const TkEnsemble *map);
@@ -359,9 +364,9 @@ typedef struct TkDisplay {
*/
Tcl_HashTable maintainHashTable;
- /* Hash table that maps from a master's
- * Tk_Window token to a list of slaves managed
- * by that master. */
+ /* Hash table that maps from a container's
+ * Tk_Window token to a list of windows managed
+ * by that container. */
int geomInit;
#define TkGetGeomMaster(tkwin) (((TkWindow *)tkwin)->maintainerPtr != NULL ? \
@@ -871,9 +876,9 @@ typedef struct TkWindow {
char *geomMgrName; /* Records the name of the geometry manager. */
struct TkWindow *maintainerPtr;
- /* The geometry master for this window. The
- * value is NULL if the window has no master or
- * if its master is its parent. */
+ /* The geometry container for this window. The
+ * value is NULL if the window has no container or
+ * if its container is its parent. */
#if !defined(TK_USE_INPUT_METHODS) && (TCL_MAJOR_VERSION < 9)
XIC inputContext; /* XIM input context. */